@@ -54,7 +54,7 @@ def format_triple_to_identifier(object_triple:tuple) -> str:
     object_triple = clean_object_triple(object_triple)
     return f"""{object_triple[0]}.{object_triple[1]}.{object_triple[2]}"""
 
-def run_single_sql_statement(q: str, params) -> pd.DataFrame:
+def run_single_sql_statement(q: str, params, df_output=True) -> pd.DataFrame:
     """
     Run a single sql statement
     :param q: query
@@ -63,8 +63,13 @@ def run_single_sql_statement(q: str, params) -> pd.DataFrame:
     """
     q = q.strip().split(';')[0]
     with sf_connection() as con:
-        r = con.cursor().execute(q, params).fetch_pandas_all()
+        if df_output is True:
+            r = con.cursor().execute(q, params).fetch_pandas_all()
+        else:
+            r = con.cursor().execute(q, params)
+            r = pd.DataFrame(r)
         con.close()
+
     return r
 
 def table_exists(object_triple:tuple) -> bool:
@@ -105,20 +110,20 @@ def create_table_if_not_exists(object_triple:tuple, columns: list):
     objectname = format_triple_to_identifier(object_triple)
     col_list = ",\n".join([f"""{c} VARCHAR""" for c in columns])
     params = (objectname, )
-    q = f"""CREATE TABLE IF NOT EXISTS IDENTIFIER(%s) (\n {col_list} , \n PRIMARY KEY (TRANSACTION_ID))"""
-    run_single_sql_statement(q, params)
+    q = f"""CREATE TABLE IF NOT EXISTS IDENTIFIER(%s) (\n {col_list} \n)"""
+    run_single_sql_statement(q, params, df_output=False)
     return None
 
 def truncate_table(object_triple:tuple):
     objectname = format_triple_to_identifier(object_triple)
     q = f"""TRUNCATE TABLE IDENTIFIER(%s)"""
     params = (objectname, )
-    run_single_sql_statement(q, params)
+    run_single_sql_statement(q, params, df_output=False)
     return None
 
 
 def prepare_table_for_upload(df, object_triple:tuple, overwrite:bool=False):
-    df_cols = df.columns.tolist()
+    df_cols = df.columns.to_list()
     if table_exists(object_triple):
         print('table exists')
         db_cols = get_columns_info(object_triple)
